@@ -1,6 +1,8 @@
 import os
 import hashlib
 from uuid import uuid4
+
+from django.db.models import Q
 from django.conf import settings
 
 
@@ -23,15 +25,11 @@ def random_filename(directory, ext=None, root=settings.MEDIA_ROOT):
     return path, filename, directory + filename
 
 
-import re
-
-
-def slugify(inStr):
-    removelist = ["a", "an", "as", "at", "before", "but", "by", "for", "from",
-        "is", "in", "into", "like", "of", "off", "on", "onto", "per", "since",
-        "than", "the", "this", "that", "to", "up", "via", "with"]
-    for a in removelist:
-        aslug = re.sub(r'\b' + a + r'\b', '', inStr)
-    aslug = re.sub('[^\w\s-]', '', aslug).strip().lower()
-    aslug = re.sub('\s+', '-', aslug)
-    return aslug
+def qsearch(qs, search_string):
+    qs = qs.filter(
+        Q(name__icontains=search_string)
+            | Q(reference__icontains=search_string)
+            | Q(id__icontains=search_string)
+            | Q(description__icontains=search_string)
+    )
+    return qs
\ No newline at end of file
